Class: Google::Apis::MerchantapiDatasourcesV1beta::DataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Overview

The data source for the Merchant Center account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSource

Returns a new instance of DataSource.



99
100
101
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 99

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_idFixnum

Output only. The data source id. Corresponds to the JSON property dataSourceId

Returns:

  • (Fixnum)


33
34
35
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 33

def data_source_id
  @data_source_id
end

#display_nameString

Required. The displayed data source name in the Merchant Center UI. Corresponds to the JSON property displayName

Returns:

  • (String)


38
39
40
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 38

def display_name
  @display_name
end

#file_inputGoogle::Apis::MerchantapiDatasourcesV1beta::FileInput

The data specific for file data sources. This field is empty for other data source inputs. Corresponds to the JSON property fileInput



44
45
46
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 44

def file_input
  @file_input
end

#inputString

Output only. Determines the type of input to the data source. Based on the input some settings might not work. Only generic data sources can be created through the API. Corresponds to the JSON property input

Returns:

  • (String)


51
52
53
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 51

def input
  @input
end

#local_inventory_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::LocalInventoryDataSource

The local inventory data source type is only available for file inputs and can' t be used to create API local inventory data sources. Corresponds to the JSON property localInventoryDataSource



57
58
59
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 57

def local_inventory_data_source
  @local_inventory_data_source
end

#merchant_review_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::MerchantReviewDataSource

The merchant review data source. Corresponds to the JSON property merchantReviewDataSource



62
63
64
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 62

def merchant_review_data_source
  @merchant_review_data_source
end

#nameString

Required. Identifier. The name of the data source. Format: accounts/account/ dataSources/datasource` Corresponds to the JSON propertyname`

Returns:

  • (String)


68
69
70
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 68

def name
  @name
end

#primary_product_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::PrimaryProductDataSource

The primary data source for local and online products. Corresponds to the JSON property primaryProductDataSource



73
74
75
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 73

def primary_product_data_source
  @primary_product_data_source
end

#product_review_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::ProductReviewDataSource

The product review data source. Corresponds to the JSON property productReviewDataSource



78
79
80
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 78

def product_review_data_source
  @product_review_data_source
end

#promotion_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::PromotionDataSource

The promotion data source. Corresponds to the JSON property promotionDataSource



83
84
85
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 83

def promotion_data_source
  @promotion_data_source
end

#regional_inventory_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::RegionalInventoryDataSource

The regional inventory data source. Corresponds to the JSON property regionalInventoryDataSource



89
90
91
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 89

def regional_inventory_data_source
  @regional_inventory_data_source
end

#supplemental_product_data_sourceGoogle::Apis::MerchantapiDatasourcesV1beta::SupplementalProductDataSource

The supplemental data source for local and online products. After creation,you should make sure to link the supplemental product data source into one or more primary product data sources. Corresponds to the JSON property supplementalProductDataSource



97
98
99
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 97

def supplemental_product_data_source
  @supplemental_product_data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 104

def update!(**args)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_input = args[:file_input] if args.key?(:file_input)
  @input = args[:input] if args.key?(:input)
  @local_inventory_data_source = args[:local_inventory_data_source] if args.key?(:local_inventory_data_source)
  @merchant_review_data_source = args[:merchant_review_data_source] if args.key?(:merchant_review_data_source)
  @name = args[:name] if args.key?(:name)
  @primary_product_data_source = args[:primary_product_data_source] if args.key?(:primary_product_data_source)
  @product_review_data_source = args[:product_review_data_source] if args.key?(:product_review_data_source)
  @promotion_data_source = args[:promotion_data_source] if args.key?(:promotion_data_source)
  @regional_inventory_data_source = args[:regional_inventory_data_source] if args.key?(:regional_inventory_data_source)
  @supplemental_product_data_source = args[:supplemental_product_data_source] if args.key?(:supplemental_product_data_source)
end