Class: Google::Apis::MerchantapiDatasourcesV1beta::DataSourceReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Overview

Data source reference can be used to manage related data sources within the data source service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSourceReference

Returns a new instance of DataSourceReference.



144
145
146
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#primary_data_source_nameString

Optional. Deprecated: Use self instead to reference the primary data source. The name of the primary data source. Format: accounts/account/dataSources/ datasource` Corresponds to the JSON propertyprimaryDataSourceName`

Returns:

  • (String)


130
131
132
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 130

def primary_data_source_name
  @primary_data_source_name
end

#selfBoolean Also known as: self?

Self should be used to reference the primary data source itself. Corresponds to the JSON property self

Returns:

  • (Boolean)


135
136
137
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 135

def self
  @self
end

#supplemental_data_source_nameString

Optional. The name of the supplemental data source. Format: accounts/account /dataSources/datasource` Corresponds to the JSON propertysupplementalDataSourceName`

Returns:

  • (String)


142
143
144
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 142

def supplemental_data_source_name
  @supplemental_data_source_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



149
150
151
152
153
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 149

def update!(**args)
  @primary_data_source_name = args[:primary_data_source_name] if args.key?(:primary_data_source_name)
  @self = args[:self] if args.key?(:self)
  @supplemental_data_source_name = args[:supplemental_data_source_name] if args.key?(:supplemental_data_source_name)
end