Class: Google::Apis::MerchantapiDatasourcesV1beta::FileUpload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Overview

The file upload of a specific data source, that is, the result of the retrieval of the data source at a certain timestamp computed asynchronously when the data source processing is finished. Only applicable to file data sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileUpload

Returns a new instance of FileUpload.



403
404
405
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_idFixnum

Output only. The data source id. Corresponds to the JSON property dataSourceId

Returns:

  • (Fixnum)


365
366
367
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 365

def data_source_id
  @data_source_id
end

#issuesArray<Google::Apis::MerchantapiDatasourcesV1beta::Issue>

Output only. The list of issues occurring in the data source. Corresponds to the JSON property issues



370
371
372
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 370

def issues
  @issues
end

#items_createdFixnum

Output only. The number of items in the data source that were created. Corresponds to the JSON property itemsCreated

Returns:

  • (Fixnum)


375
376
377
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 375

def items_created
  @items_created
end

#items_totalFixnum

Output only. The number of items in the data source that were processed. Corresponds to the JSON property itemsTotal

Returns:

  • (Fixnum)


380
381
382
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 380

def items_total
  @items_total
end

#items_updatedFixnum

Output only. The number of items in the data source that were updated. Corresponds to the JSON property itemsUpdated

Returns:

  • (Fixnum)


385
386
387
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 385

def items_updated
  @items_updated
end

#nameString

Identifier. The name of the data source file upload. Format: datasource.name= accounts/`account`/dataSources/`datasource`/fileUploads/`fileupload Corresponds to the JSON propertyname`

Returns:

  • (String)


391
392
393
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 391

def name
  @name
end

#processing_stateString

Output only. The processing state of the data source. Corresponds to the JSON property processingState

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 396

def processing_state
  @processing_state
end

#upload_timeString

Output only. The date at which the file of the data source was uploaded. Corresponds to the JSON property uploadTime

Returns:

  • (String)


401
402
403
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 401

def upload_time
  @upload_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



408
409
410
411
412
413
414
415
416
417
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 408

def update!(**args)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @issues = args[:issues] if args.key?(:issues)
  @items_created = args[:items_created] if args.key?(:items_created)
  @items_total = args[:items_total] if args.key?(:items_total)
  @items_updated = args[:items_updated] if args.key?(:items_updated)
  @name = args[:name] if args.key?(:name)
  @processing_state = args[:processing_state] if args.key?(:processing_state)
  @upload_time = args[:upload_time] if args.key?(:upload_time)
end