Class: Google::Apis::MerchantapiDatasourcesV1beta::Issue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Overview

An error occurring in the data source, like "invalid price".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Issue

Returns a new instance of Issue.



459
460
461
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Output only. The code of the error, for example, "validation/invalid_value". Returns "?" if the code is unknown. Corresponds to the JSON property code

Returns:

  • (String)


429
430
431
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 429

def code
  @code
end

#countFixnum

Output only. The number of occurrences of the error in the file upload. Corresponds to the JSON property count

Returns:

  • (Fixnum)


434
435
436
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 434

def count
  @count
end

#descriptionString

Output only. The error description, for example, "Your data source contains items which have too many attributes, or are too big. These items will be dropped". Corresponds to the JSON property description

Returns:

  • (String)


441
442
443
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 441

def description
  @description
end

#documentation_uriString

Output only. Link to the documentation explaining the issue in more details, if available. Corresponds to the JSON property documentationUri

Returns:

  • (String)


447
448
449
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 447

def documentation_uri
  @documentation_uri
end

#severityString

Output only. The severity of the issue. Corresponds to the JSON property severity

Returns:

  • (String)


452
453
454
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 452

def severity
  @severity
end

#titleString

Output only. The title of the issue, for example, "Item too big". Corresponds to the JSON property title

Returns:

  • (String)


457
458
459
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 457

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



464
465
466
467
468
469
470
471
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 464

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @count = args[:count] if args.key?(:count)
  @description = args[:description] if args.key?(:description)
  @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri)
  @severity = args[:severity] if args.key?(:severity)
  @title = args[:title] if args.key?(:title)
end