Class: Google::Apis::MerchantapiDatasourcesV1beta::LocalInventoryDataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Overview

The local inventory data source type is only available for file inputs and can' t be used to create API local inventory data sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalInventoryDataSource

Returns a new instance of LocalInventoryDataSource.



513
514
515
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_languageString

Required. Immutable. The two-letter ISO 639-1 language of the items to which the local inventory is provided. Corresponds to the JSON property contentLanguage

Returns:

  • (String)


504
505
506
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 504

def content_language
  @content_language
end

#feed_labelString

Required. Immutable. The feed label of the offers to which the local inventory is provided. Must be less than or equal to 20 uppercase letters (A-Z), numbers (0-9), and dashes (-). Corresponds to the JSON property feedLabel

Returns:

  • (String)


511
512
513
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 511

def feed_label
  @feed_label
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



518
519
520
521
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 518

def update!(**args)
  @content_language = args[:content_language] if args.key?(:content_language)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
end