Class: Google::Apis::MerchantapiDatasourcesV1beta::RegionalInventoryDataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalInventoryDataSource

Returns a new instance of RegionalInventoryDataSource.



788
789
790
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_languageString

Required. Immutable. The two-letter ISO 639-1 language of the items to which the regional inventory is provided. Corresponds to the JSON property contentLanguage

Returns:

  • (String)


779
780
781
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 779

def content_language
  @content_language
end

#feed_labelString

Required. Immutable. The feed label of the offers to which the regional inventory is provided. Must be less than or equal to 20 uppercase letters (A-Z) , numbers (0-9), and dashes (-). Corresponds to the JSON property feedLabel

Returns:

  • (String)


786
787
788
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 786

def feed_label
  @feed_label
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



793
794
795
796
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 793

def update!(**args)
  @content_language = args[:content_language] if args.key?(:content_language)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
end