Class: Google::Apis::MerchantapiDatasourcesV1beta::DataSourceReference
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiDatasourcesV1beta::DataSourceReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb
Overview
Data source reference can be used to manage related data sources within the data source service.
Instance Attribute Summary collapse
-
#primary_data_source_name ⇒ String
Optional.
-
#self ⇒ Boolean
(also: #self?)
Self should be used to reference the primary data source itself.
-
#supplemental_data_source_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSourceReference
constructor
A new instance of DataSourceReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSourceReference
Returns a new instance of DataSourceReference.
143 144 145 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#primary_data_source_name ⇒ String
Optional. The name of the primary data source. Format: accounts/account/
dataSources/datasource`
Corresponds to the JSON propertyprimaryDataSourceName`
129 130 131 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 129 def primary_data_source_name @primary_data_source_name end |
#self ⇒ Boolean Also known as: self?
Self should be used to reference the primary data source itself.
Corresponds to the JSON property self
134 135 136 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 134 def self @self end |
#supplemental_data_source_name ⇒ String
Optional. The name of the supplemental data source. Format: accounts/account
/dataSources/datasource`
Corresponds to the JSON propertysupplementalDataSourceName`
141 142 143 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 141 def supplemental_data_source_name @supplemental_data_source_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
148 149 150 151 152 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 148 def update!(**args) @primary_data_source_name = args[:primary_data_source_name] if args.key?(:primary_data_source_name) @self = args[:self] if args.key?(:self) @supplemental_data_source_name = args[:supplemental_data_source_name] if args.key?(:supplemental_data_source_name) end |