Class: Google::Apis::MerchantapiDatasourcesV1beta::FetchSettings
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiDatasourcesV1beta::FetchSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb
Overview
Fetch details to deliver the data source.
Instance Attribute Summary collapse
-
#day_of_month ⇒ Fixnum
Optional.
-
#day_of_week ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#fetch_uri ⇒ String
Optional.
-
#frequency ⇒ String
Required.
-
#password ⇒ String
Optional.
-
#time_of_day ⇒ Google::Apis::MerchantapiDatasourcesV1beta::TimeOfDay
Represents a time of day.
-
#time_zone ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchSettings
constructor
A new instance of FetchSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchSettings
Returns a new instance of FetchSettings.
304 305 306 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_month ⇒ Fixnum
Optional. The day of the month when the data source file should be fetched (1-
31). This field can only be set for monthly frequency.
Corresponds to the JSON property dayOfMonth
252 253 254 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 252 def day_of_month @day_of_month end |
#day_of_week ⇒ String
Optional. The day of the week when the data source file should be fetched.
This field can only be set for weekly frequency.
Corresponds to the JSON property dayOfWeek
258 259 260 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 258 def day_of_week @day_of_week end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Enables or pauses the fetch schedule.
Corresponds to the JSON property enabled
263 264 265 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 263 def enabled @enabled end |
#fetch_uri ⇒ String
Optional. The URL where the data source file can be fetched. Google Merchant
Center supports automatic scheduled uploads using the HTTP, HTTPS or SFTP
protocols, so the value will need to be a valid link using one of those three
protocols. Immutable for Google Sheets files.
Corresponds to the JSON property fetchUri
272 273 274 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 272 def fetch_uri @fetch_uri end |
#frequency ⇒ String
Required. The frequency describing fetch schedule.
Corresponds to the JSON property frequency
277 278 279 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 277 def frequency @frequency end |
#password ⇒ String
Optional. An optional password for fetch_uri. Used for submitting data
sources through SFTP.
Corresponds to the JSON property password
283 284 285 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 283 def password @password end |
#time_of_day ⇒ Google::Apis::MerchantapiDatasourcesV1beta::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property timeOfDay
290 291 292 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 290 def time_of_day @time_of_day end |
#time_zone ⇒ String
Optional. Time zone used for schedule. UTC by
default. For example, "America/Los_Angeles".
Corresponds to the JSON property timeZone
296 297 298 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 296 def time_zone @time_zone end |
#username ⇒ String
Optional. An optional user name for fetch_uri. Used for submitting data
sources through SFTP.
Corresponds to the JSON property username
302 303 304 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 302 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 309 def update!(**args) @day_of_month = args[:day_of_month] if args.key?(:day_of_month) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @enabled = args[:enabled] if args.key?(:enabled) @fetch_uri = args[:fetch_uri] if args.key?(:fetch_uri) @frequency = args[:frequency] if args.key?(:frequency) @password = args[:password] if args.key?(:password) @time_of_day = args[:time_of_day] if args.key?(:time_of_day) @time_zone = args[:time_zone] if args.key?(:time_zone) @username = args[:username] if args.key?(:username) end |