Class: Google::Apis::MerchantapiDatasourcesV1beta::FileUpload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb

Overview

The file upload of a specific data source, that is, the result of the retrieval of the data source at a certain timestamp computed asynchronously when the data source processing is finished. Only applicable to file data sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileUpload

Returns a new instance of FileUpload.



399
400
401
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_idFixnum

Output only. The data source id. Corresponds to the JSON property dataSourceId

Returns:

  • (Fixnum)


361
362
363
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 361

def data_source_id
  @data_source_id
end

#issuesArray<Google::Apis::MerchantapiDatasourcesV1beta::Issue>

Output only. The list of issues occurring in the data source. Corresponds to the JSON property issues



366
367
368
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 366

def issues
  @issues
end

#items_createdFixnum

Output only. The number of items in the data source that were created. Corresponds to the JSON property itemsCreated

Returns:

  • (Fixnum)


371
372
373
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 371

def items_created
  @items_created
end

#items_totalFixnum

Output only. The number of items in the data source that were processed. Corresponds to the JSON property itemsTotal

Returns:

  • (Fixnum)


376
377
378
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 376

def items_total
  @items_total
end

#items_updatedFixnum

Output only. The number of items in the data source that were updated. Corresponds to the JSON property itemsUpdated

Returns:

  • (Fixnum)


381
382
383
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 381

def items_updated
  @items_updated
end

#nameString

Identifier. The name of the data source file upload. Format: datasource.name= accounts/`account`/dataSources/`datasource`/fileUploads/`fileupload Corresponds to the JSON propertyname`

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 387

def name
  @name
end

#processing_stateString

Output only. The processing state of the data source. Corresponds to the JSON property processingState

Returns:

  • (String)


392
393
394
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 392

def processing_state
  @processing_state
end

#upload_timeString

Output only. The date at which the file of the data source was uploaded. Corresponds to the JSON property uploadTime

Returns:

  • (String)


397
398
399
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 397

def upload_time
  @upload_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



404
405
406
407
408
409
410
411
412
413
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 404

def update!(**args)
  @data_source_id = args[:data_source_id] if args.key?(:data_source_id)
  @issues = args[:issues] if args.key?(:issues)
  @items_created = args[:items_created] if args.key?(:items_created)
  @items_total = args[:items_total] if args.key?(:items_total)
  @items_updated = args[:items_updated] if args.key?(:items_updated)
  @name = args[:name] if args.key?(:name)
  @processing_state = args[:processing_state] if args.key?(:processing_state)
  @upload_time = args[:upload_time] if args.key?(:upload_time)
end