Class: Google::Apis::MerchantapiDatasourcesV1beta::Issue
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiDatasourcesV1beta::Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb
Overview
An error occurring in the data source, like "invalid price".
Instance Attribute Summary collapse
-
#code ⇒ String
Output only.
-
#count ⇒ Fixnum
Output only.
-
#description ⇒ String
Output only.
-
#documentation_uri ⇒ String
Output only.
-
#severity ⇒ String
Output only.
-
#title ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Issue
constructor
A new instance of Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Issue
Returns a new instance of Issue.
459 460 461 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Output only. The code of the error, for example, "validation/invalid_value".
Returns "?" if the code is unknown.
Corresponds to the JSON property code
429 430 431 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 429 def code @code end |
#count ⇒ Fixnum
Output only. The number of occurrences of the error in the file upload.
Corresponds to the JSON property count
434 435 436 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 434 def count @count end |
#description ⇒ String
Output only. The error description, for example, "Your data source contains
items which have too many attributes, or are too big. These items will be
dropped".
Corresponds to the JSON property description
441 442 443 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 441 def description @description end |
#documentation_uri ⇒ String
Output only. Link to the documentation explaining the issue in more details,
if available.
Corresponds to the JSON property documentationUri
447 448 449 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 447 def documentation_uri @documentation_uri end |
#severity ⇒ String
Output only. The severity of the issue.
Corresponds to the JSON property severity
452 453 454 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 452 def severity @severity end |
#title ⇒ String
Output only. The title of the issue, for example, "Item too big".
Corresponds to the JSON property title
457 458 459 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 457 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
464 465 466 467 468 469 470 471 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 464 def update!(**args) @code = args[:code] if args.key?(:code) @count = args[:count] if args.key?(:count) @description = args[:description] if args.key?(:description) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @severity = args[:severity] if args.key?(:severity) @title = args[:title] if args.key?(:title) end |