Class: Google::Apis::MerchantapiDatasourcesV1beta::Issue
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiDatasourcesV1beta::Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb
Overview
An error occurring in the data source, like "invalid price".
Instance Attribute Summary collapse
-
#code ⇒ String
Output only.
-
#count ⇒ Fixnum
Output only.
-
#description ⇒ String
Output only.
-
#documentation_uri ⇒ String
Output only.
-
#severity ⇒ String
Output only.
-
#title ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Issue
constructor
A new instance of Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Issue
Returns a new instance of Issue.
458 459 460 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 458 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Output only. The code of the error, for example, "validation/invalid_value".
Returns "?" if the code is unknown.
Corresponds to the JSON property code
428 429 430 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 428 def code @code end |
#count ⇒ Fixnum
Output only. The number of occurrences of the error in the file upload.
Corresponds to the JSON property count
433 434 435 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 433 def count @count end |
#description ⇒ String
Output only. The error description, for example, "Your data source contains
items which have too many attributes, or are too big. These items will be
dropped".
Corresponds to the JSON property description
440 441 442 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 440 def description @description end |
#documentation_uri ⇒ String
Output only. Link to the documentation explaining the issue in more details,
if available.
Corresponds to the JSON property documentationUri
446 447 448 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 446 def documentation_uri @documentation_uri end |
#severity ⇒ String
Output only. The severity of the issue.
Corresponds to the JSON property severity
451 452 453 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 451 def severity @severity end |
#title ⇒ String
Output only. The title of the issue, for example, "Item too big".
Corresponds to the JSON property title
456 457 458 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 456 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
463 464 465 466 467 468 469 470 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 463 def update!(**args) @code = args[:code] if args.key?(:code) @count = args[:count] if args.key?(:count) @description = args[:description] if args.key?(:description) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @severity = args[:severity] if args.key?(:severity) @title = args[:title] if args.key?(:title) end |