Class: Google::Apis::MerchantapiDatasourcesV1beta::ProductStatusChangeMessage
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiDatasourcesV1beta::ProductStatusChangeMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb
Overview
The message that the merchant will receive to notify about product status change event
Instance Attribute Summary collapse
-
#account ⇒ String
The target account that owns the entity that changed.
-
#attribute ⇒ String
The attribute in the resource that changed, in this case it will be always
Status. -
#changes ⇒ Array<Google::Apis::MerchantapiDatasourcesV1beta::ProductChange>
A message to describe the change that happened to the product Corresponds to the JSON property
changes. -
#event_time ⇒ String
The time at which the event was generated.
-
#expiration_time ⇒ String
Optional.
-
#managing_account ⇒ String
The account that manages the merchant's account.
-
#resource ⇒ String
The product name.
-
#resource_id ⇒ String
The product id.
-
#resource_type ⇒ String
The resource that changed, in this case it will always be
Product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductStatusChangeMessage
constructor
A new instance of ProductStatusChangeMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductStatusChangeMessage
Returns a new instance of ProductStatusChangeMessage.
728 729 730 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account ⇒ String
The target account that owns the entity that changed. Format : accounts/
merchant_id`
Corresponds to the JSON propertyaccount`
681 682 683 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 681 def account @account end |
#attribute ⇒ String
The attribute in the resource that changed, in this case it will be always
Status.
Corresponds to the JSON property attribute
687 688 689 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 687 def attribute @attribute end |
#changes ⇒ Array<Google::Apis::MerchantapiDatasourcesV1beta::ProductChange>
A message to describe the change that happened to the product
Corresponds to the JSON property changes
692 693 694 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 692 def changes @changes end |
#event_time ⇒ String
The time at which the event was generated. If you want to order the
notification messages you receive you should rely on this field not on the
order of receiving the notifications.
Corresponds to the JSON property eventTime
699 700 701 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 699 def event_time @event_time end |
#expiration_time ⇒ String
Optional. The product expiration time. This field will not be set if the
notification is sent for a product deletion event.
Corresponds to the JSON property expirationTime
705 706 707 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 705 def expiration_time @expiration_time end |
#managing_account ⇒ String
The account that manages the merchant's account. can be the same as merchant
id if it is standalone account. Format : accounts/service_provider_id`
Corresponds to the JSON propertymanagingAccount`
711 712 713 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 711 def managing_account @managing_account end |
#resource ⇒ String
The product name. Format: accounts/account/products/product`
Corresponds to the JSON propertyresource`
716 717 718 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 716 def resource @resource end |
#resource_id ⇒ String
The product id.
Corresponds to the JSON property resourceId
721 722 723 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 721 def resource_id @resource_id end |
#resource_type ⇒ String
The resource that changed, in this case it will always be Product.
Corresponds to the JSON property resourceType
726 727 728 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 726 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 733 def update!(**args) @account = args[:account] if args.key?(:account) @attribute = args[:attribute] if args.key?(:attribute) @changes = args[:changes] if args.key?(:changes) @event_time = args[:event_time] if args.key?(:event_time) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @managing_account = args[:managing_account] if args.key?(:managing_account) @resource = args[:resource] if args.key?(:resource) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_type = args[:resource_type] if args.key?(:resource_type) end |