Class: Google::Apis::MerchantapiDatasourcesV1beta::SupplementalProductDataSource
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiDatasourcesV1beta::SupplementalProductDataSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_datasources_v1beta/classes.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb,
lib/google/apis/merchantapi_datasources_v1beta/representations.rb
Overview
The supplemental data source for local and online products. After creation,you should make sure to link the supplemental product data source into one or more primary product data sources.
Instance Attribute Summary collapse
-
#content_language ⇒ String
Optional.
-
#feed_label ⇒ String
Optional.
-
#referencing_primary_data_sources ⇒ Array<Google::Apis::MerchantapiDatasourcesV1beta::DataSourceReference>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupplementalProductDataSource
constructor
A new instance of SupplementalProductDataSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupplementalProductDataSource
Returns a new instance of SupplementalProductDataSource.
838 839 840 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_language ⇒ String
Optional. Immutable. The two-letter ISO 639-1 language of the items in the
data source. feedLabel and contentLanguage must be either both set or
unset. The fields can only be unset for data sources without file input. If
set, the data source will only accept products matching this combination. If
unset, the data source will accept produts without that restriction.
Corresponds to the JSON property contentLanguage
817 818 819 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 817 def content_language @content_language end |
#feed_label ⇒ String
Optional. Immutable. The feed label that is specified on the data source level.
Must be less than or equal to 20 uppercase letters (A-Z), numbers (0-9), and
dashes (-). feedLabel and contentLanguage must be either both set or unset
for data sources with product content type. They must be set for data sources
with a file input. The fields must be unset for data sources without file
input. If set, the data source will only accept products matching this
combination. If unset, the data source will accept produts without that
restriction.
Corresponds to the JSON property feedLabel
829 830 831 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 829 def feed_label @feed_label end |
#referencing_primary_data_sources ⇒ Array<Google::Apis::MerchantapiDatasourcesV1beta::DataSourceReference>
Output only. The (unordered and deduplicated) list of all primary data sources
linked to this data source in either default or custom rules. Supplemental
data source cannot be deleted before all links are removed.
Corresponds to the JSON property referencingPrimaryDataSources
836 837 838 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 836 def referencing_primary_data_sources @referencing_primary_data_sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
843 844 845 846 847 |
# File 'lib/google/apis/merchantapi_datasources_v1beta/classes.rb', line 843 def update!(**args) @content_language = args[:content_language] if args.key?(:content_language) @feed_label = args[:feed_label] if args.key?(:feed_label) @referencing_primary_data_sources = args[:referencing_primary_data_sources] if args.key?(:referencing_primary_data_sources) end |